{% extends BASE_TEMPLATE %}

{% load staticfiles %}

{% block action-btn %}
  <div class="fixed-action-btn">
    <a class="btn-floating btn-large red">
      <i class="large material-icons">add</i>
    </a>
    <ul>
      <!-- <li><a class="btn-floating red lighten-1 tooltipped" data-position="left" data-delay="50" data-tooltip="Test"><i class="material-icons">insert_chart</i></a></li> -->
      <li><a class="btn-floating yellow lighten-1 tooltipped" data-position="left" data-delay="50" data-tooltip="Upload Parts" href="{% url 'upload-parts' %}"><i class="material-icons">cloud_upload</i></a></li>
      <li><a class="btn-floating blue lighten-1 tooltipped" data-position="left" data-delay="50" data-tooltip="New Part" href="{% url 'create-part' %}"><i class="material-icons">library_add</i></a></li>
    </ul>
  </div>
{% endblock %}
